Method: ActiveCMIS::Repository#latest_changelog_token
- Defined in:
- lib/active_cmis/repository.rb
#latest_changelog_token ⇒ String
Changelog token representing the most recent change to this repository (will represent the most recent change at the time that this ActiveCMIS::Repository was created
93 94 95 |
# File 'lib/active_cmis/repository.rb', line 93 def latest_changelog_token @changelog_token ||= data.xpath("cra:repositoryInfo/c:latestChangeLogToken", NS::COMBINED).text end |